package scacchi.main;

/**
 * Classe contenitore per le eccezioni sollevate durante l'analisi
 * delle stringhe degli argomenti dei comandi e rappresentate con le
 * classi definite in {@link ArgomentiComando}. <br>
 * La classe contiene solo static nested classes e non pu&ograve; essere
 * istanziata o estesa.
 * @author Stefano Guerrini
 * @version 04/12/10
 * @see ArgomentiComando
 */
public final class EccezioniTesto {
    /** Questa classe non puo' essere istanziata. */
    private EccezioniTesto() {};

    /** Radice della gerachia di eccezioni */
    public static class NotazioneException extends Exception {
	/** @param s La stringa con il messaggio di errore. */
	public NotazioneException(String s) { super(s); }
    }

    /** Eccezione per stringa di argomenti non validi. */
    public static class ArgomentiException extends NotazioneException {
	/** @param s La stringa di argomenti non valids. */
	public ArgomentiException(String s) {
	    super("Stringa di argomenti non valida: '" + s + "'");
	}
    }

    /** Eccezione per valore intero non valido. */
    public static class ValInteroException extends NotazioneException {
	/** @param s La stringa del valore intero non valido. */
	public ValInteroException(String s) {
	    super("Valore intero non valido: '" + s + "'");
	}
    }

    /** Eccezione per valore numerico (intero senza segno) non valido. */
    public static class ValNumericoException extends NotazioneException {
	/** @param s La stringa del valore numerico non valido. */
	public ValNumericoException(String s) {
	    super("Valore numerico non valido: '" + s + "'");
	}
    }

    /** Eccezione per mossa non valida. */
    public static class MossaTestoException extends NotazioneException  {
	/** @param s La stringa della mossa non valida. */
	public MossaTestoException(String s) {
	    super("Mossa non valida: " + "'" + s + "'");
	}
    }

    /** Eccezione per posizione di pezzo non valida. */
    public static class PosPezzoException extends NotazioneException  {
	/** @param s La stringa della posizione di pezzo non valida. */
	public PosPezzoException(String s) {
	    super("Posizione pezzo non valida: " + "'" + s + "'");
	}
    }

    /** Eccezione per simbolo di pezzo non valido. */
    public static class SimboloPezzoException extends NotazioneException  {
	/** 
	 *  @param s La stringa contenente il simbolo di pezzo non valido.
	 *  @param i La posizione del simbolo nella stringa.
	 */
	public SimboloPezzoException(String s, int i) {
	    super("Simbolo pezzo non valido: '" + 
		  s.charAt(i) + "' in '" + s + "'");
	}
    }

    /** Eccezione per casa non valida. */
    public static class CasaTestoException extends NotazioneException {
	/** @param s La stringa della casa non valida. */
	public CasaTestoException(String s) { 
	    super("Casa non valida: '" + s + "'");
	}
    }

    /** Eccezione per colonna non valida. */
    public static class ColonnaTestoException extends NotazioneException {
	/** 
	 *  @param s La stringa con il codice della colonna non valido.
	 *  @param i La posizione del codice nella stringa.
	 */
	public ColonnaTestoException(String s, int i) {
	    super("Colonna non valida: '" + s.charAt(i) + "' in '" + s + "'");
	}
    }

    /** Eccezione per traversa non valida. */
    public static class TraversaTestoException extends NotazioneException {
	/** 
	 *  @param s La stringa con il codice della traversa non valido.
	 *  @param i La posizione del codice nella stringa.
	 */
	public TraversaTestoException(String s, int i) {
	    super("Traversa non valida: '" + s.charAt(i) + "' in '" + s + "'");
	}
    }
}
